@@ -16,9 +16,7 @@ my $Re1 = {
 };
 
 my $ReFailure = {
-    'mesgtoobig' => qr{
-        Mail[ ]size[ ]limit[ ]exceeded
-    }x,
+    'mesgtoobig' => qr/Mail[ ]size[ ]limit[ ]exceeded/x,
 };
 
 my $Indicators = __PACKAGE__->INDICATORS;
@@ -148,9 +146,9 @@ sub scan {
     for my $e ( @$dscontents ) {
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         $e->{'diagnosis'} =~ s/\A$Re1->{'error'}//g;
@@ -164,7 +162,7 @@ sub scan {
         }
 
         $e->{'status'} =  Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
-        $e->{'spec'} ||= 'SMTP';
+        $e->{'spec'}   = 'SMTP';
         $e->{'agent'}  = __PACKAGE__->smtpagent;
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
@@ -213,7 +211,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
