@@ -12,25 +12,19 @@ my $Re0 = {
 };
 my $Re1 = {
     'begin' => qr/\AYour[ ]mail[ ](?:
-                     sent[ ]on:?[ ][A-Z][a-z]{2}[,]
-                    |attempted[ ]to[ ]be[ ]delivered[ ]on:?[ ][A-Z][a-z]{2}[,]
-                    )
-               /x,
+         sent[ ]on:?[ ][A-Z][a-z]{2}[,]
+        |attempted[ ]to[ ]be[ ]delivered[ ]on:?[ ][A-Z][a-z]{2}[,]
+        )
+    /x,
     'rfc822' => qr|\AContent-Type: message/rfc822\z|,
     'error'  => qr/Could not be delivered to:? /,
     'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
 
 my $ReFailure = {
-    'mailboxfull' => qr{
-        As[ ]their[ ]mailbox[ ]is[ ]full
-    }x,
-    'norelaying' => qr{
-        Due[ ]to[ ]the[ ]following[ ]SMTP[ ]relay[ ]error
-    }x,
-    'hostunknown' => qr{
-        As[ ]the[ ]remote[ ]domain[ ]doesnt[ ]exist
-    }x,
+    'mailboxfull' => qr/As[ ]their[ ]mailbox[ ]is[ ]full/x,
+    'norelaying'  => qr/Due[ ]to[ ]the[ ]following[ ]SMTP[ ]relay[ ]error/x,
+    'hostunknown' => qr/As[ ]the[ ]remote[ ]domain[ ]doesnt[ ]exist/x,
 };
 
 my $Indicators = __PACKAGE__->INDICATORS;
@@ -42,7 +36,7 @@ sub smtpagent   { 'JP::KDDI' }
 sub pattern     { return $Re0 }
 
 sub scan {
-    # Detect an error from KDDI
+    # Detect an error from au by KDDI
     # @param         [Hash] mhead       Message header of a bounce email
     # @options mhead [String] from      From header
     # @options mhead [String] date      Date header
@@ -154,9 +148,9 @@ sub scan {
     for my $e ( @$dscontents ) {
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
@@ -233,7 +227,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
