@@ -4,6 +4,9 @@ use feature ':5.10';
 use strict;
 use warnings;
 
+my $ReE = {
+    'from'      => qr/[@].+[.]mail[.]ru[>]?/,
+};
 my $Re0 = {
     'from'      => qr/\AMail Delivery System/,
     'subject'   => qr{(?:
@@ -45,17 +48,17 @@ my $Re1 = {
     'alias'  => qr/\A([ ]+an[ ]undisclosed[ ]address)\z/,
     'frozen' => qr/\AMessage .+ (?:has been frozen|was frozen on arrival)/,
     'rfc822' => qr{\A(?:
-                     [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message.+headers[.][ ][-]+
-                    |Content-Type:[ ]*message/rfc822
-                    )\z
-                }x,
+         [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message.+headers[.][ ][-]+
+        |Content-Type:[ ]*message/rfc822
+        )\z
+    }x,
     'begin'  => qr{\A(?>
-                     This[ ]message[ ]was[ ]created[ ]automatically[ ]by[ ]mail[ ]delivery[ ]software[.]
-                    |A[ ]message[ ]that[ ]you[ ]sent[ ]was[ ]rejected[ ]by[ ]the[ ]local[ ]scanning[ ]code
-                    |Message[ ].+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival)
-                    |The[ ].+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
-                    )
-                   }x,
+         This[ ]message[ ]was[ ]created[ ]automatically[ ]by[ ]mail[ ]delivery[ ]software[.]
+        |A[ ]message[ ]that[ ]you[ ]sent[ ]was[ ]rejected[ ]by[ ]the[ ]local[ ]scanning[ ]code
+        |Message[ ].+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival)
+        |The[ ].+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
+        )
+    }x,
     'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
 
@@ -132,6 +135,8 @@ my $RFC822Head = Sisimai::RFC5322->HEADERFIELDS;
 
 sub description { 'Exim' }
 sub smtpagent   { 'Exim' }
+
+# X-Failed-Recipients: kijitora@example.ed.jp
 sub headerlist  { return [ 'X-Failed-Recipients' ] }
 sub pattern     { return $Re0 }
 
@@ -152,9 +157,11 @@ sub scan {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
+    return undef if     $mhead->{'from'}    =~ $ReE->{'from'};
     return undef unless $mhead->{'from'}    =~ $Re0->{'from'};
     return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
 
+    require Sisimai::String;
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -164,7 +171,6 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $localhost0 = '';    # (String) Local MTA
     my $boundary00 = '';    # (String) Boundary string
-    my $rxboundary = undef; # (String) Regular expression for matching with the boundary
     my $v = undef;
 
     if( $mhead->{'content-type'} ) {
@@ -172,7 +178,6 @@ sub scan {
         # the boundary string.
         require Sisimai::MIME;
         $boundary00 = Sisimai::MIME->boundary( $mhead->{'content-type'} );
-        $rxboundary = qr/\A[-]{2}$boundary00\z/ if length $boundary00;
     }
 
     for my $e ( @hasdivided ) {
@@ -352,7 +357,6 @@ sub scan {
         $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from[ \t]([^ ]+) /;
     }
 
-    require Sisimai::String;
     require Sisimai::SMTP::Reply;
     require Sisimai::SMTP::Status;
 
@@ -410,7 +414,7 @@ sub scan {
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
         $e->{'diagnosis'} =~ s{\b__.+\z}{};
 
-        if( ! $e->{'rhost'} ) {
+        unless( $e->{'rhost'} ) {
             # Get the remote host name
             if( $e->{'diagnosis'} =~ m/host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/ ) {
                 # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
@@ -420,13 +424,13 @@ sub scan {
             unless( $e->{'rhost'} ) {
                 if( scalar @{ $mhead->{'received'} } ) {
                     # Get localhost and remote host name from Received header.
-                    my $r = $mhead->{'received'};
-                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+                    my $r0 = $mhead->{'received'};
+                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
                 }
             }
         }
 
-        if( ! $e->{'command'} ) {
+        unless( $e->{'command'} ) {
             # Get the SMTP command name for the session
             SMTP: for my $r ( @$ReCommand ) {
                 # Verify each regular expression of SMTP commands
@@ -581,7 +585,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
