@@ -296,7 +296,7 @@ sub takeapart {
 
     for my $e ( @hasdivided ) {
         # Header name as a key, The value of header as a value
-        if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
+        if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.*)\z/ ) {
             # Header
             my $lhs = lc $1;
             my $rhs = $2;
@@ -327,6 +327,7 @@ sub takeapart {
 
             } else {
                 # ASCII Characters only: Not MIME-Encoded
+                $e =~ s/\A[ \t]+//; # unfolding
                 $takenapart->{ $previousfn }  .= $e;
                 $mimeborder->{ $previousfn } //= 0;
             }
@@ -566,7 +567,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
