@@ -10,15 +10,15 @@ my $Re0 = {
     'from'        => qr/\b(?:postmaster|mailer-daemon|root)[@]/i,
     'return-path' => qr/(?:[<][>]|mailer-daemon)/i,
     'subject'     => qr{(?>
-                         delivery[ ](?:failed|failure|report)
-                        |failure[ ]notice
-                        |mail[ ](?:delivery|error)
-                        |non[-]delivery
-                        |returned[ ]mail
-                        |undeliverable[ ]mail
-                        |Warning:[ ]
-                        )
-                     }xi,
+         delivery[ ](?:failed|failure|report)
+        |failure[ ]notice
+        |mail[ ](?:delivery|error)
+        |non[-]delivery
+        |returned[ ]mail
+        |undeliverable[ ]mail
+        |Warning:[ ]
+        )
+    }xi,
 };
 
 my $Re1 = {
@@ -287,7 +287,7 @@ sub scan {
                         #   a message to one or more recipients.  In all cases, the Reporting-MTA
                         #   is the MTA that attempted to perform the delivery, relay, or gateway
                         #   operation described in the DSN.  This field is required.
-                        $connheader->{'rhost'} ||= $1;
+                        $connheader->{'rhost'} ||= lc $1;
 
                     } elsif( $e =~ m/\A[Rr]eceived-[Ff]rom-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                         # 2.2.4 The Received-From-MTA DSN field
@@ -302,7 +302,7 @@ sub scan {
                         #   supplied in the HELO or EHLO command, and the network address used by
                         #   the SMTP client SHOULD be included as a comment enclosed in
                         #   parentheses.  (In this case, the MTA-name-type will be "dns".)
-                        $connheader->{'lhost'} = $1;
+                        $connheader->{'lhost'} = lc $1;
 
                     } elsif( $e =~ m/\A[Aa]rrival-[Dd]ate:[ ]*(.+)\z/ ) {
                         # 2.2.5 The Arrival-Date DSN field
@@ -477,9 +477,9 @@ sub scan {
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         $e->{'date'}  ||= $mhead->{'date'};
@@ -530,7 +530,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
