@@ -6,26 +6,26 @@ use warnings;
 sub text  { 'toomanyconn' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.1.26
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          All[ ]available[ ]IPs[ ]are[ ]at[ ]maximum[ ]connection[ ]limit    # SendGrid
         |connection[ ]rate[ ]limit[ ]exceeded
         |no[ ]IPs[ ]available[ ][-][ ].+[ ]exceeds[ ]per[-]domain[ ]connection[ ]limit[ ]for
         |Too[ ]many[ ](?:
              connections
-            |connections[ ]from[ ]your[ ]host[.]    # Microsoft 
+            |connections[ ]from[ ]your[ ]host[.]    # Microsoft
             |concurrent[ ]SMTP[ ]connections        # Microsoft
             |SMTP[ ]sessions[ ]for[ ]this[ ]host    # Sendmail(daemon.c)
             )
         )
     }xi;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -42,18 +42,15 @@ sub true {
     return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     my $statuscode = $argvs->deliverystatus // '';
+    my $diagnostic = $argvs->diagnosticcode // '';
+    my $tempreason = Sisimai::SMTP::Status->name( $statuscode );
     my $reasontext = __PACKAGE__->text;
-    my $tempreason = '';
-    my $diagnostic = '';
     my $v = 0;
 
-    $tempreason = Sisimai::RFC3463->reason( $statuscode ) if $statuscode;
-    $diagnostic = $argvs->diagnosticcode // '';
-
     if( $tempreason eq $reasontext ) {
-        # Delivery status code points "blocked".
+        # Delivery status code points "toomanyconn".
         $v = 1;
 
     } else {
@@ -114,8 +111,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
