@@ -96,6 +96,9 @@ sub list {
         RFC5322.pm
         Rhost.pm
             Rhost/GoogleApps.pm
+        SMTP.pm
+            SMTP/Reply.pm
+            SMTP/Status.pm
         String.pm
         Time.pm
     | ];
